# Volume Electron Microscropy DENoising (vEMden)

This package performs automatic (unsupervised) denoising of volume electron microscopy images. Two deep learning 
architectures are available:
<ul>
<li>Noise Reconstruction & Remove Network (NRRN)</li>
<li>DenoiseNet</li>
</ul>

For installation, more information/details and full examples with code and data, visit:
https://www.thibault.biz/Research/VolumeEM/vEMden/vEMden.html
